| runSGWT | R Documentation |
Perform SGWT analysis on all signals in the SGWT object. Uses batch processing for multiple signals when possible for efficiency. Assumes Graph slot is populated by runSpecGraph().
runSGWT(SG, use_batch = TRUE, verbose = TRUE)
SG |
SGWT object with Graph slot populated |
use_batch |
Whether to use batch processing for multiple signals (default: TRUE) |
verbose |
Whether to print progress messages (default: TRUE) |
Updated SGWT object with Forward and Inverse slots populated
# Create example data
data <- data.frame(x = runif(100), y = runif(100), signal = rnorm(100))
SG <- initSGWT(data, signals = "signal")
SG <- runSpecGraph(SG, k = 15)
# Uses batch processing by default
SG <- runSGWT(SG)
# Or force individual processing
SG2 <- initSGWT(data, signals = "signal")
SG2 <- runSpecGraph(SG2, k = 15)
SG2 <- runSGWT(SG2, use_batch = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.